==> sl-cia-2.0.74.tgz: package/lib/sl-config-cia-cli.js <==
﻿var nopt = require("nopt"),    
    noptUsage = require("nopt-usage"),
    fs = require("fs"),
    readJsonSync = require('read-json-sync');

var SEALIGHTS_JSON_FILENAME = "./sealights.json";

var knownOpts = {
    "customerid" : String
    , "server": String
    , "proxy" : String
    , "nodejsexcludedpaths" : String
    , "help": Boolean
},
    shortHands = {
        "h": ["--help"]
    },

    description = {
        "customerid": " Customer ID (mandatory, unless already exists in sealights.json)",
        "server": " SeaLights Server URL",
        "proxy": " Proxy server (optional, must be a valid URL)",
        "help": " Show this help page", 
        "nodejsexcludedpaths": "NodeJS Only. Comma-separated list of excluded paths glob strings, in the form of 'public/**/*.js,files/**/*.js'. The default value is test/**/*.js. The node_modules folder is always excluded."
    },

    defaults = {
        "help": "",
    };

var parsedArgs = parseCommandLineArguments();
if (parsedArgs.help) {
    printUsage();
    process.exit(1);
} else {
    updateOrCreateCfg();
}

function updateOrCreateCfg() {
    
    var cfg = {
        "server": "http://www.sealights.io/api",
        "interval": 10000,
        "enabled": true
    };
    var forceRewrite = false;
    var readExistingCfgFileResult = readExistingCfgFile(SEALIGHTS_JSON_FILENAME) || {};
    if (readExistingCfgFileResult.error) {
        console.error("ERROR: " + readExistingCfgFileResult.error);
        process.exit(1);
    }
    else if (readExistingCfgFileResult.cfg) {
        cfg = readExistingCfgFileResult.cfg;
    } else {
        forceRewrite = true;
    }
    
    if (updateCfgFromAgruments(cfg, parsedArgs) > 0) {
        forceRewrite = true;
    }
    
    validateCfg(cfg);
    
    if (forceRewrite) {
        writeFile(cfg);
    } else {
        console.log('No changes made to ' + SEALIGHTS_JSON_FILENAME);
    }
}

function parseCommandLineArguments() {
    var parsedArgs = nopt(knownOpts, shortHands, process.argv, 2);
    return parsedArgs;
}

function printUsage() {
    try {
        var usage = noptUsage(knownOpts, shortHands, description, defaults);
        console.log('Usage: sl-config-cia -customerid [customerid] -server [server] -proxy [proxy]');
        console.log(usage);
    } catch (e) {
        console.log(e);
    }
}

function readExistingCfgFile(filename) {
    if (fs.existsSync(filename)) {
        try {
            var loadedCfg = readJsonSync(filename);
            if (Object.prototype.toString.call(loadedCfg) !== "[object Object]")
                throw "File content is not a valid JSON object";
            return { cfg: loadedCfg };
        } catch (e) {
            return { error: filename + " cannot be read and is probably corrupted. Please delete it and re-run.", cfg: null };
        }
    }
}

function updateCfgFromAgruments(cfg, parsedArgs) {
    function updateField(name, cfgProperty, argName) {
        if (parsedArgs[argName]) {
            console.log("Updating " + name + " = " + parsedArgs[argName]);
            cfg[cfgProperty] = parsedArgs[argName];
            return true;
        }
        return false;
    }
    var changedFields = 0;
    if (updateField("Customer Id", "customerId", "customerid")) changedFields++;
    if (updateField("Server", "server", "server")) changedFields++;
    if (updateField("Proxy", "proxy", "proxy")) changedFields++;    
    if (updateField("Node.js excluded paths", "nodeJsExcludedPaths", "nodejsexcludedpaths")) changedFields++;
    
    
    return changedFields;
    
}

function validateCfg(cfg) {
    if (!cfg.customerId)
        console.warn("WARNING: Configuration file is missing the required 'customerId' field");
    if (!cfg.server)
        console.warn("WARNING: Configuration file is missing the required 'server' field");
}

function writeFile(cfg) {
    try {
        console.log('Writing file ' + SEALIGHTS_JSON_FILENAME);
        var json = JSON.stringify(cfg, null, '\t');
        fs.writeFileSync(SEALIGHTS_JSON_FILENAME, json);
        console.log('Done.');
    } catch (e) {
        console.error('Error writing to file ' + SEALIGHTS_JSON_FILENAME + ": " + e);
    }
}

==> sl-cia-2.0.87.tgz: package/lib/sl-config-cia-cli.js <==
﻿var nopt = require("nopt"),    
    noptUsage = require("nopt-usage"),
    fs = require("fs"),
    readJsonSync = require('read-json-sync');

var SEALIGHTS_JSON_FILENAME = "./sealights.json";

var knownOpts = {
    "customerid" : String
    , "server": String
    , "proxy" : String
    , "nodejsexcludedpaths" : String
    , "usebranchcoverage": Boolean
    , "help": Boolean
},
    shortHands = {
        "h": ["--help"]
    },

    description = {
        "customerid": " Customer ID (mandatory, unless already exists in sealights.json)",
        "server": " SeaLights Server URL",
        "proxy": " Proxy server (optional, must be a valid URL)",
        "help": " Show this help page", 
        "nodejsexcludedpaths": "NodeJS Only. Comma-separated list of excluded paths glob strings, in the form of 'public/**/*.js,files/**/*.js'. The default value is test/**/*.js. The node_modules folder is always excluded.",
        "usebranchcoverage": "Optional. Include branches in scan"
    },

    defaults = {
        "help": "",
    };

var parsedArgs = parseCommandLineArguments();
if (parsedArgs.help) {
    printUsage();
    process.exit(1);
} else {
    updateOrCreateCfg();
}

function updateOrCreateCfg() {
    
    var cfg = {
        "server": "http://www.sealights.io/api",
        "interval": 10000,
        "enabled": true
    };
    var forceRewrite = false;
    var readExistingCfgFileResult = readExistingCfgFile(SEALIGHTS_JSON_FILENAME) || {};
    if (readExistingCfgFileResult.error) {
        console.error("ERROR: " + readExistingCfgFileResult.error);
        process.exit(1);
    }
    else if (readExistingCfgFileResult.cfg) {
        cfg = readExistingCfgFileResult.cfg;
    } else {
        forceRewrite = true;
    }
    
    if (updateCfgFromAgruments(cfg, parsedArgs) > 0) {
        forceRewrite = true;
    }
    
    validateCfg(cfg);
    
    if (forceRewrite) {
        writeFile(cfg);
    } else {
        console.log('No changes made to ' + SEALIGHTS_JSON_FILENAME);
    }
}

function parseCommandLineArguments() {
    var parsedArgs = nopt(knownOpts, shortHands, process.argv, 2);
    return parsedArgs;
}

function printUsage() {
    try {
        var usage = noptUsage(knownOpts, shortHands, description, defaults);
        console.log('Usage: sl-config-cia -customerid [customerid] -server [server] -proxy [proxy]');
        console.log(usage);
    } catch (e) {
        console.log(e);
    }
}

function readExistingCfgFile(filename) {
    if (fs.existsSync(filename)) {
        try {
            var loadedCfg = readJsonSync(filename);
            if (Object.prototype.toString.call(loadedCfg) !== "[object Object]")
                throw "File content is not a valid JSON object";
            return { cfg: loadedCfg };
        } catch (e) {
            return { error: filename + " cannot be read and is probably corrupted. Please delete it and re-run.", cfg: null };
        }
    }
}

function updateCfgFromAgruments(cfg, parsedArgs) {
    function updateField(name, cfgProperty, argName) {
        if (parsedArgs[argName]) {
            console.log("Updating " + name + " = " + parsedArgs[argName]);
            cfg[cfgProperty] = parsedArgs[argName];
            return true;
        }
        return false;
    }
    var changedFields = 0;
    if (updateField("Customer Id", "customerId", "customerid")) changedFields++;
    if (updateField("Server", "server", "server")) changedFields++;
    if (updateField("Proxy", "proxy", "proxy")) changedFields++;    
    if (updateField("Node.js excluded paths", "nodeJsExcludedPaths", "nodejsexcludedpaths")) changedFields++;
    if (updateField("Branch Coverage", "useBranchCoverage", "usebranchcoverage")) changedFields++;
    
    return changedFields;
    
}

function validateCfg(cfg) {
    if (!cfg.customerId)
        console.warn("WARNING: Configuration file is missing the required 'customerId' field");
    if (!cfg.server)
        console.warn("WARNING: Configuration file is missing the required 'server' field");
}

function writeFile(cfg) {
    try {
        console.log('Writing file ' + SEALIGHTS_JSON_FILENAME);
        var json = JSON.stringify(cfg, null, '\t');
        fs.writeFileSync(SEALIGHTS_JSON_FILENAME, json);
        console.log('Done.');
    } catch (e) {
        console.error('Error writing to file ' + SEALIGHTS_JSON_FILENAME + ": " + e);
    }
}
